<?php namespace ProcessWire;
include_once('MenuRenderer.inc');
/*
 * Menu Renderer for RepeaterFlex using UiKit3
 *
 * This variant of a Menu Renderer generates markup for UiKit3 menus.
 */
class UkMenuRenderer extends MenuRenderer {
	public static function getModuleInfo() { return [
		'title' => __('Menu Renderer for UiKit', __FILE__), // Module Title
		'summary' => __('Renders RepeaterFlex with depth information for a UiKit Menu.', __FILE__), // Module Summary
		'version' => 1,
		];
	}

	public static function getConfigFields() { return [
		'menuid' => [
				'type' => 'InputfieldText',
				'label' => __('Menu ID'),
//				'required' => 1,
				'columnWidth' => 50,
			],
		'collapsemobile' => [
				'type' => 'InputfieldCheckbox',
				'label' => __('Collapse on small devices'),
//				'required' => 1,
				'columnWidth' => 50,
			],
		]; }

	private $menuID = '';
	protected $appendMarkup = '';

	public function renderPrefix() {
		$menuAppend = '';
		if(isset($this->menuid))
			$this->menuID = $this->menuid;
		else
			$this->menuID = 'menu'.wire('page')->id;	// use some default menu id if none defined
		$this->offCanvas = '';
		if($this->bForOffCanvas)	// Generate markup for mobile devices?
			return("
<div id='{$this->menuID}-oc' uk-offcanvas='mode: push; overlay: true' class='uk-offcanvas'>
 <div class='uk-offcanvas-bar'>
   <ul class='uk-nav-default uk-nav-parent-icon' uk-nav>
");

		return( "
 <div id='{$this->menuID}' uk-sticky='media: 960; sel-target: .uk-navbar-container; cls-active: uk-navbar-sticky' class='uk-box-shadow-medium'>
 <nav class='uk-navbar-container' uk-navbar>
"); }
	public function renderSuffix() {
		if($this->bForOffCanvas)
			return( "
    </ul>
 </div>
</div>
");
		return('
 </nav>
</div>
'.$this->appendMarkup); }

	public function menuAppend(string $markup) { $this->appendMarkup .= $markup; }
	public function getMenuID() { return($this->menuID); }
	public function getMainTitle($TextLine, $directLink='')
		{
		if(!$directLink)
			$directLink = '#';
		if($this->bForOffCanvas)
			{
			$this->setCloseTag("</ul></li>");
			return("<li class='uk-parent'><a href='{$directLink}'>{$TextLine}</a><ul class='uk-nav-sub'>");
			}
		$this->setCloseTag("</ul></div></div></div></li>");
		$atts = '';
		if($this->collapsemobile)
			$atts = ' class="uk-visible@m"';
		return("<li{$atts}><a href='{$directLink}'>{$TextLine}</a><div class='uk-width-large' uk-dropdown><div class='uk-dropdown-grid' uk-grid><div class='uk-width-1-1'><ul class='uk-dropdown-nav uk-nav-parent-icon' uk-nav>");
		}
	public function getLink($title, $url, $targetOrAttributeArray='_blank')
		{
		$atts = $this->getExpandedAttributes($targetOrAttributeArray);
//		if($this->bForOffCanvas)
//			return("<a href='{$url}' $atts>{$title}</a><br/>");
		return("<li><a href='{$url}' $atts>{$title}</a></li>");
		}

	public function getWrap()
		{
		if($this->bForOffCanvas)
			return("<hr/>");
		return("</ul></div><div><ul class='uk-nav uk-dropdown-nav'>");
		}
	public function getItemTitle($TextLine)
		{
		return(" <li class='uk-nav-header'>{$TextLine}</li>");
		}
	public function getSeparator()
		{
		return(" <li class='uk-nav-divider'></li>");
		}
	public function getPageLink(Page $pg, $bEnumerateChildren=false, $bIsHeadline=false) {
		$out = '';
		if($bIsHeadline)
			$targetAtt = [ 'style' => 'font-weight:bold;' ];
		else
			$targetAtt = '';
		$sel = '';
		if(wire('user')->isSuperuser())
			$sel = 'include=hidden';
		if($pg->id)
			{
			if($bEnumerateChildren && (count($pg->children()) > 0))
				{
				if($this->bForOffCanvas)
					{
					$out = $this->getLink($pg->title, $pg->url, $targetAtt, $this->bForOffCanvas);
					}
				else
					{
					$out .= "<li class='uk-parent'><a href='#'>{$pg->title}</a><ul class='uk-nav-sub'>";
					$out .= $this->getPageLink($pg, false);
					foreach($pg->children($sel) as $child)
						{
						$out .= $this->getPageLink($child, $bEnumerateChildren);
						}
					$out .= "</ul></li>";
					}
				}
			else
				$out = $this->getLink($pg->title, $pg->url, $targetAtt, $this->bForOffCanvas, $bIsHeadline);
			}
		return($out);
		}
	}
